import axios from '@/utils/axios'
import { type AxiosResponse } from 'axios'
import {
  LoginInputDto,
  RegisterInputDto,
  Token,
  TokenRefreshPayload,
  User,
} from './user.interface'

export async function register(data: RegisterInputDto) {
  return axios.post<Token>('/api/users', data)
}

export async function login(data: LoginInputDto) {
  return axios.post<Token>('/api/users/token', data)
}

let refreshing: Promise<AxiosResponse<Token>> | null
export async function refreshToken(data: TokenRefreshPayload) {
  if (!refreshing) {
    refreshing = axios.put<Token>('/api/users/me/token', data).finally(() => {
      refreshing = null
    })
  }
  return refreshing
}

export async function getUserInfo() {
  return axios.get<User>('/api/users/me')
}
